### Tests
- `test_smith_normal_form.py`
  - reproduce Table3 in [1]
- `test_superlattice.py`
  - reproduce https://oeis.org/A001001
  - reproduce https://oeis.org/A045790
  - reproduce Table4 in [1]
  - reproduce Table1 in [2]
- `test_permutation.py`
  - check if permutation is valid and unique
- `test_enumeration.py`
  - reproduce Table4 in [1] up to index = 8
  - reproduce Table6 in [1]
  - reproduce Table7 in [1] up to index = 8
  - reproduce Table2 in [2] up to index = 8
- `test_derivative_structure.py`
  - reproduce Fig2 in [1]
  - reproduce Fig11 in [1]
- not tested figures or tables
  - [1]
    - fig3
    - fig9
    - fig10

### Refs.
1. https://journals.aps.org/prb/abstract/10.1103/PhysRevB.77.224115
1. https://journals.aps.org/prb/abstract/10.1103/PhysRevB.80.014120
